<?php defined('SYSPATH') or die('No direct access allowed.');

/**
 * This class provides User SSL functions
 *
 * @package    SSL
 * @category   Controllers/User
 * @author     Deon George
 * @copyright  (c) 2009-2013 Deon George
 * @license    http://dev.leenooks.net/license.html
 */
class Controller_User_SSL extends Controller_SSL {
	protected $auth_required = TRUE;

	protected $secure_actions = array(
		'add'=>0,
		'download'=>0,
		'view'=>0,
	);

	public function action_add() {
		if ($this->request->post()) {
			$so = ORM::factory('SSL');

			$so->account_id = (string)Auth::instance()->get_user();

			// Set our values, so that our filters have data
			$so->values($this->request->post());
 
			$this->save($so);

			if ($so->saved())
				HTTP::redirect(URL::link('user','ssl/view/'.$so->id));
		}

		Block::factory()
			->type('form-horizontal')
			->title('Add/Edit Record')
			->title_icon('fa-wrench')
			->body(View::factory('ssl/user/add')->set('o',$this->ao));
	}

	public function action_download() {
		$passwd_len = Kohana::$config->load('ssl')->minpass_length;

		$so = ORM::factory('SSL',$this->request->post('sid'));

		if (! $so->loaded() OR ! Auth::instance()->authorised($so->account))
			throw HTTP_Exception::factory(403,'SSL either doesnt exist, or you are not authorised to see it');

		if ($passwd_len) {
			$passwd = $this->request->post('passwd');

			if (strlen($passwd) < $passwd_len) {
				SystemMessage::add(array(
					'title'=>_('Validation failed'),
					'type'=>'danger',
					'body'=>_('Your requested password is too short.'),
				));

				HTTP::redirect(URL::link('user','ssl/view/'.$so->id));
			}
		}

		$this->auto_render = FALSE;
		$this->response->headers('Content-Type','plain/text');
		$this->response->headers('Content-Disposition','attachment; filename="'.$this->ao->id().'.crt"');
		$this->response->body($so->cert);
	}

	public function action_view() {
		$so = ORM::factory('SSL',$this->request->param('id'));

		if (! $so->loaded() OR ! Auth::instance()->authorised($so->account))
			throw HTTP_Exception::factory(403,'SSL either doesnt exist, or you are not authorised to see it');

		if ($this->request->post()) {
			$so->account_id = (string)Auth::instance()->get_user();

			// Set our values, so that our filters have data
			$so->values($this->request->post());
 
			if ($so->changed() AND ! $this->save($so))
				$so->reload();

			if ($so->saved())
				HTTP::redirect(URL::link('user','ssl/view/'.$so->id));
		}

		Block::factory()
			->title('SSL Certificate')
			->title_icon('fa-certificate')
			->body(View::factory('ssl/user/view')->set('o',$so));
	}
}
?>
